pub enum ResponseError<E> {
UsedLength {
used: u32,
},
ResponseLimit,
HeaderAccess(E),
PayloadAccess(E),
RequestId {
expected: u64,
actual: u64,
},
Flags(u16),
PayloadLength {
expected: u64,
actual: u32,
},
PayloadEncoding,
ObjectId,
DeviceInfo(DeviceInfoError),
EventState(u16),
EventStatus {
state: u16,
error: StatusCode,
},
}Expand description
Malformed or inaccessible device response.
Variants
UsedLength
Used length cannot contain the required response header or exact payload.
ResponseLimit
The response exceeds the negotiated frame limit.
HeaderAccess(E)
The response header cannot be read.
PayloadAccess(E)
The response payload cannot be read.
RequestId
Response request ID does not match the chain’s request.
Flags(u16)
Protocol 1.0 response flags are nonzero.
PayloadLength
Payload shape does not match the operation and status.
PayloadEncoding
A fixed payload cannot be decoded from its exact bytes.
ObjectId
A successful object-creation response returned object ID zero.
DeviceInfo(DeviceInfoError)
Device discovery returned invalid limits or reserved values.
EventState(u16)
Event state uses an unknown numeric value.
EventStatus
Event state and error status contradict each other.