pub struct StaleOperation<O> { /* private fields */ }Expand description
Operation metadata recovered only after its queue epoch is stale.
Implementations
Sourceimpl<O> StaleOperation<O>
impl<O> StaleOperation<O>
Sourcepub const fn request_id(&self) -> u64
pub const fn request_id(&self) -> u64
Request identifier from the invalidated queue epoch.
Sourcepub const fn epoch(&self) -> QueueEpoch
pub const fn epoch(&self) -> QueueEpoch
Invalidated queue epoch.
Sourcepub fn into_operation(self) -> O
pub fn into_operation(self) -> O
Recover operation metadata for cleanup or inspection.
Typed handles from this operation remain stale and cannot be republished in the new epoch.